"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = require("react");
var popper_utils_1 = require("popper.js/dist/esm/popper-utils");
function useParentScroll(elementRef, onScroll) {
    react_1.useEffect(function () {
        if (!elementRef.current || !onScroll) {
            return function () { return null; };
        }
        var dom = elementRef.current;
        // https://github.com/FezVrasta/popper.js/blob/master/packages/popper/src/utils/setupEventListeners.js
        var scrollParents = [];
        var scrollParent = popper_utils_1.getScrollParent(dom);
        while (scrollParent) {
            var isBody = scrollParent.nodeName === "BODY";
            var target = isBody
                ? scrollParent.ownerDocument.defaultView
                : scrollParent;
            target.addEventListener("scroll", onScroll, { passive: true });
            scrollParents.push(target);
            if (isBody) {
                break;
            }
            scrollParent = popper_utils_1.getScrollParent(popper_utils_1.getParentNode(scrollParent));
        }
        scrollParent = null;
        return function () {
            scrollParents.forEach(function (parent) {
                return parent.removeEventListener("scroll", onScroll);
            });
            scrollParents = null;
        };
    }, [Boolean(onScroll), elementRef.current]); // eslint-disable-line react-hooks/exhaustive-deps
}
exports.useParentScroll = useParentScroll;
//# sourceMappingURL=use-parent-scroll.js.map