import { useEffect, RefObject } from "react";
import {
  getScrollParent,
  getParentNode,
} from "popper.js/dist/esm/popper-utils";

export function useParentScroll(
  elementRef: RefObject<HTMLElement>,
  onScroll: (event: Event) => void
) {
  useEffect(() => {
    if (!elementRef.current || !onScroll) {
      return () => null;
    }

    const dom = elementRef.current;

    // https://github.com/FezVrasta/popper.js/blob/master/packages/popper/src/utils/setupEventListeners.js
    let scrollParents: (HTMLElement | Window)[] = [];
    let scrollParent: HTMLElement = getScrollParent(dom);
    while (scrollParent) {
      const isBody = scrollParent.nodeName === "BODY";
      const target = isBody
        ? scrollParent.ownerDocument.defaultView
        : scrollParent;
      target.addEventListener("scroll", onScroll, { passive: true });
      scrollParents.push(target);
      if (isBody) {
        break;
      }
      scrollParent = getScrollParent(getParentNode(scrollParent));
    }
    scrollParent = null;

    return () => {
      scrollParents.forEach(parent =>
        parent.removeEventListener("scroll", onScroll)
      );
      scrollParents = null;
    };
  }, [Boolean(onScroll), elementRef.current]); // eslint-disable-line react-hooks/exhaustive-deps
}
