import React from "react";
import classNames from "classnames";
import { useTranslation } from "../i18n";
import { StyledProps } from "../_type";

export interface FoundTipProps extends StyledProps {
  /**
   * 找到结果的文案
   * @default "找到下列结果"
   */
  foundText?: React.ReactNode;

  /**
   * 清空结果提示文案
   * @default "返回原列表"
   */
  clearResultText?: React.ReactNode;

  /**
   * 返回原列表时回调，如果不传则不渲染此操作
   */
  onClear?: () => void;
}

export function FoundTip({
  foundText,
  onClear,
  clearResultText,
  className,
  style,
}: FoundTipProps) {
  const t = useTranslation();
  const text = foundText || t.foundText;
  return (
    <span className={classNames("tea-action-state", className)} style={style}>
      {typeof text === "string" ? (
        <span className="tea-action-state__text">{text}</span>
      ) : (
        text
      )}
      {onClear && (
        <>
          {" "}
          <a
            href="javascript:;"
            className="tea-action-state__text"
            onClick={onClear}
          >
            {clearResultText || t.clearResultText}
          </a>
        </>
      )}
    </span>
  );
}
