import { ScalePoint, ScaleLinear, Selection, BaseType, NestedArray, ScaleBand } from "d3";
import { Context } from "../context";
export declare class RectCoordinate {
    /**
     * 上下文
     */
    private ctx;
    /**
     * X 轴映射字段
     */
    xKey: string;
    /**
     * Y 轴映射字段
     */
    yKey: string;
    /**
     * 数据系列映射字段
     */
    serieKey: string;
    /**
     * X 轴比例尺类型
     */
    XScaleType: "Band" | "Point";
    /**
     * X 轴比例尺
     */
    xScale: ScalePoint<string> | [ScaleBand<string>, ScaleBand<string>];
    /**
     * Y 轴比例尺
     */
    yScale: ScaleLinear<number, number>;
    /**
     * X 轴实例对象
     */
    xAxis: Selection<SVGGElement, {}, BaseType, {}>;
    /**
     * Y 轴实例对象
     */
    yAxis: Selection<SVGGElement, {}, BaseType, {}>;
    /**
     * 辅助线绘制层
     */
    helperLayout: Selection<SVGGElement, {}, BaseType, {}>;
    /**
     * 结构化数据
     */
    nestedData: NestedArray<{
        [key: string]: number | string | null;
    }, string>;
    /**
     * 当高亮某数据系列时需要暂存原始值
     */
    private savedNestedData;
    /**
     * 禁用的数据系列名
     */
    private disabledKeys;
    constructor(ctx: Context);
    /**
     * 设置数据映射
     * @param x X 轴映射字段
     * @param y Y 轴映射字段
     */
    setPosition(x: string, y: string): void;
    /**
     * 设置数据系列映射
     * @param serieKey 数据系列字段
     */
    setSerie(serieKey: string): void;
    /**
     * 设置 X 轴比例尺类型
     * @param type 比例尺类型
     */
    setXScaleType(type: this["XScaleType"]): void;
    update(): void;
    /**
     * 绘制坐标系
     */
    draw(): void;
    /**
     * 更新数据比例尺
     */
    private updateScale;
    /**
     * 更新坐标轴
     */
    private updateAxes;
    /**
     * 绘制 PointScale 类型的 X 坐标轴
     * @param offset Y 轴 Label 的宽度
     */
    private drawXAxisWithPointScale;
    /**
     * 绘制 BandScale 类型的 X 坐标轴
     * @param offset Y 轴 Label 的宽度
     */
    private drawXAxisWithBandScale;
    private drawYAxis;
    /**
     * 统一设置样式
     */
    private style;
    private onEnter;
    private onLeft;
    private onMoved;
    /**
     * 图例点击事件
     * @param legendData 被点击的图例信息
     * @param disabled 改图例元素是否是禁用状态
     */
    private onLegendClick;
}
