import { event, Selection, BaseType } from "d3";
import { Context } from "./context";

export class EventListener {
  /**
   * 上下文
   */
  private ctx: Context;

  /**
   * 事件层元素
   */
  private selection: Selection<SVGRectElement, {}, BaseType, {}>;

  public constructor(ctx: Context) {
    this.ctx = ctx;
    const { selection: plot, width, height } = this.ctx.plot;
    this.selection = plot
      .append("rect")
      .style("height", height)
      .style("width", width)
      .attr("fill", "transparent")
      .attr("pointer-events", "all");
    this.start();
  }

  /**
   * 开始监听事件
   */
  private start() {
    if ("ontouchstart" in document) {
      this.selection
        .style("-webkit-tap-highlight-color", "transparent")
        .on("touchmove", this.plotMoved.bind(this))
        .on("touchstart", this.plotEntered.bind(this))
        .on("touchend", this.plotLeft.bind(this));
    } else {
      this.selection
        .on("mousemove", this.plotMoved.bind(this))
        .on("mouseenter", this.plotEntered.bind(this))
        .on("mouseleave", this.plotLeft.bind(this));
    }
  }

  /**
   * 监测鼠标移动
   */
  private plotMoved() {
    event.preventDefault();
    this.ctx.emit("plot.moved", event.layerX, event.layerY);
  }

  /**
   * 监测鼠标进入绘图区
   */
  private plotEntered() {
    this.ctx.emit("plot.entered");
  }

  /**
   * 监测鼠标离开绘图区
   */
  private plotLeft() {
    this.ctx.emit("plot.left");
  }
}
