import React from "react";
import classNames from "classnames";
import { StyledProps } from "../_type";

export interface JustifyProps extends StyledProps {
  /**
   * 是否顶部对齐
   * @default false
   */
  top?: boolean;

  /**
   * 是否底部对齐
   * @default false
   */
  bottom?: boolean;

  /**
   * 左侧内容
   */
  left?: React.ReactNode;

  /**
   * 右侧内容
   */
  right?: React.ReactNode;
}

export function Justify({
  left,
  right,
  top,
  bottom,
  className,
  style,
}: JustifyProps) {
  return (
    <div
      className={classNames("tea-justify-grid", className, {
        "tea-justify-grid--start": top,
        "tea-justify-grid--end": bottom,
      })}
      style={style}
    >
      {left != null && (
        <div className="tea-justify-grid__col tea-justify-grid__col--left">
          {left}
        </div>
      )}
      {right != null && (
        <div className="tea-justify-grid__col tea-justify-grid__col--right">
          {right}
        </div>
      )}
    </div>
  );
}
