import React from "react";
import classNames from "classnames";
import { StyledProps } from "../_type";

export interface MediaObjectProps extends StyledProps {
  /**
   * 媒体元素
   */
  media: React.ReactNode;

  /**
   * 内容块
   */
  children: React.ReactNode;

  /**
   * 媒体元素与内容块对齐方式
   * @default "top"
   */
  align?: "top" | "middle" | "bottom";

  /**
   * 媒体元素与内容块反置
   * @default false
   */
  reverse?: boolean;
}

export function MediaObject({
  align = "top",
  reverse,
  media,
  children,
}: MediaObjectProps) {
  return (
    <div
      className={classNames("tea-media", {
        "tea-media tea-media--reverse": reverse,
        "tea-media tea-media--middle": align === "middle",
        "tea-media tea-media--bottom": align === "bottom",
      })}
    >
      <div className="tea-media__left">{media}</div>
      <div className="tea-media__body">{children}</div>
    </div>
  );
}
