import React from "react";
import classNames from "classnames";
import { Icon } from "../icon";
import { useTranslation } from "../i18n";
import { StyledProps } from "../_type";

export interface LoadingTipProps extends StyledProps {
  /**
   * 加载文案
   * @default "加载中..."
   */
  loadingText?: React.ReactNode;

  /**
   * 隐藏图标
   * @default false
   */
  hideIcon?: boolean;
}

export function LoadingTip(props: LoadingTipProps) {
  const t = useTranslation();
  const { hideIcon, className, style, loadingText = t.loadingText } = props;
  return (
    <span className={classNames("tea-action-state", className)} style={style}>
      {!hideIcon && <Icon type="loading" className="tea-mr-2n" />}
      {typeof loadingText === "string" ? (
        <span className="tea-action-state__text">{loadingText}</span>
      ) : (
        loadingText
      )}
    </span>
  );
}
