/*
 * Tencent is pleased to support the open source community by making TKEStack
 * available.
 *
 * Copyright (C) 2012-2019 Tencent. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use
 * this file except in compliance with the License. You may obtain a copy of the
 * License at
 *
 * https://opensource.org/licenses/Apache-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

// Code generated by client-gen. DO NOT EDIT.

package internalversion

import (
	"time"

	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
	auth "tkestack.io/tke/api/auth"
	scheme "tkestack.io/tke/api/client/clientset/internalversion/scheme"
)

// APIKeysGetter has a method to return a APIKeyInterface.
// A group's client should implement this interface.
type APIKeysGetter interface {
	APIKeys() APIKeyInterface
}

// APIKeyInterface has methods to work with APIKey resources.
type APIKeyInterface interface {
	Create(*auth.APIKey) (*auth.APIKey, error)
	Update(*auth.APIKey) (*auth.APIKey, error)
	UpdateStatus(*auth.APIKey) (*auth.APIKey, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*auth.APIKey, error)
	List(opts v1.ListOptions) (*auth.APIKeyList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *auth.APIKey, err error)
	APIKeyExpansion
}

// aPIKeys implements APIKeyInterface
type aPIKeys struct {
	client rest.Interface
}

// newAPIKeys returns a APIKeys
func newAPIKeys(c *AuthClient) *aPIKeys {
	return &aPIKeys{
		client: c.RESTClient(),
	}
}

// Get takes name of the aPIKey, and returns the corresponding aPIKey object, and an error if there is any.
func (c *aPIKeys) Get(name string, options v1.GetOptions) (result *auth.APIKey, err error) {
	result = &auth.APIKey{}
	err = c.client.Get().
		Resource("apikeys").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of APIKeys that match those selectors.
func (c *aPIKeys) List(opts v1.ListOptions) (result *auth.APIKeyList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &auth.APIKeyList{}
	err = c.client.Get().
		Resource("apikeys").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested aPIKeys.
func (c *aPIKeys) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("apikeys").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a aPIKey and creates it.  Returns the server's representation of the aPIKey, and an error, if there is any.
func (c *aPIKeys) Create(aPIKey *auth.APIKey) (result *auth.APIKey, err error) {
	result = &auth.APIKey{}
	err = c.client.Post().
		Resource("apikeys").
		Body(aPIKey).
		Do().
		Into(result)
	return
}

// Update takes the representation of a aPIKey and updates it. Returns the server's representation of the aPIKey, and an error, if there is any.
func (c *aPIKeys) Update(aPIKey *auth.APIKey) (result *auth.APIKey, err error) {
	result = &auth.APIKey{}
	err = c.client.Put().
		Resource("apikeys").
		Name(aPIKey.Name).
		Body(aPIKey).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *aPIKeys) UpdateStatus(aPIKey *auth.APIKey) (result *auth.APIKey, err error) {
	result = &auth.APIKey{}
	err = c.client.Put().
		Resource("apikeys").
		Name(aPIKey.Name).
		SubResource("status").
		Body(aPIKey).
		Do().
		Into(result)
	return
}

// Delete takes name of the aPIKey and deletes it. Returns an error if one occurs.
func (c *aPIKeys) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Resource("apikeys").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *aPIKeys) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Resource("apikeys").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched aPIKey.
func (c *aPIKeys) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *auth.APIKey, err error) {
	result = &auth.APIKey{}
	err = c.client.Patch(pt).
		Resource("apikeys").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
