/*
 * Tencent is pleased to support the open source community by making TKEStack
 * available.
 *
 * Copyright (C) 2012-2019 Tencent. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use
 * this file except in compliance with the License. You may obtain a copy of the
 * License at
 *
 * https://opensource.org/licenses/Apache-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

// Code generated by client-gen. DO NOT EDIT.

package internalversion

import (
	"time"

	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
	auth "tkestack.io/tke/api/auth"
	scheme "tkestack.io/tke/api/client/clientset/internalversion/scheme"
)

// ClientsGetter has a method to return a ClientInterface.
// A group's client should implement this interface.
type ClientsGetter interface {
	Clients() ClientInterface
}

// ClientInterface has methods to work with Client resources.
type ClientInterface interface {
	Create(*auth.Client) (*auth.Client, error)
	Update(*auth.Client) (*auth.Client, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*auth.Client, error)
	List(opts v1.ListOptions) (*auth.ClientList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *auth.Client, err error)
	ClientExpansion
}

// clients implements ClientInterface
type clients struct {
	client rest.Interface
}

// newClients returns a Clients
func newClients(c *AuthClient) *clients {
	return &clients{
		client: c.RESTClient(),
	}
}

// Get takes name of the client, and returns the corresponding client object, and an error if there is any.
func (c *clients) Get(name string, options v1.GetOptions) (result *auth.Client, err error) {
	result = &auth.Client{}
	err = c.client.Get().
		Resource("clients").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of Clients that match those selectors.
func (c *clients) List(opts v1.ListOptions) (result *auth.ClientList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &auth.ClientList{}
	err = c.client.Get().
		Resource("clients").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested clients.
func (c *clients) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("clients").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a client and creates it.  Returns the server's representation of the client, and an error, if there is any.
func (c *clients) Create(client *auth.Client) (result *auth.Client, err error) {
	result = &auth.Client{}
	err = c.client.Post().
		Resource("clients").
		Body(client).
		Do().
		Into(result)
	return
}

// Update takes the representation of a client and updates it. Returns the server's representation of the client, and an error, if there is any.
func (c *clients) Update(client *auth.Client) (result *auth.Client, err error) {
	result = &auth.Client{}
	err = c.client.Put().
		Resource("clients").
		Name(client.Name).
		Body(client).
		Do().
		Into(result)
	return
}

// Delete takes name of the client and deletes it. Returns an error if one occurs.
func (c *clients) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Resource("clients").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *clients) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Resource("clients").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched client.
func (c *clients) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *auth.Client, err error) {
	result = &auth.Client{}
	err = c.client.Patch(pt).
		Resource("clients").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
