/*
 * Tencent is pleased to support the open source community by making TKEStack
 * available.
 *
 * Copyright (C) 2012-2019 Tencent. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use
 * this file except in compliance with the License. You may obtain a copy of the
 * License at
 *
 * https://opensource.org/licenses/Apache-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

// Code generated by client-gen. DO NOT EDIT.

package v1

import (
	"time"

	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
	scheme "tkestack.io/tke/api/client/clientset/versioned/scheme"
	v1 "tkestack.io/tke/api/platform/v1"
)

// LBCFsGetter has a method to return a LBCFInterface.
// A group's client should implement this interface.
type LBCFsGetter interface {
	LBCFs() LBCFInterface
}

// LBCFInterface has methods to work with LBCF resources.
type LBCFInterface interface {
	Create(*v1.LBCF) (*v1.LBCF, error)
	Update(*v1.LBCF) (*v1.LBCF, error)
	UpdateStatus(*v1.LBCF) (*v1.LBCF, error)
	Delete(name string, options *metav1.DeleteOptions) error
	Get(name string, options metav1.GetOptions) (*v1.LBCF, error)
	List(opts metav1.ListOptions) (*v1.LBCFList, error)
	Watch(opts metav1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.LBCF, err error)
	LBCFExpansion
}

// lBCFs implements LBCFInterface
type lBCFs struct {
	client rest.Interface
}

// newLBCFs returns a LBCFs
func newLBCFs(c *PlatformV1Client) *lBCFs {
	return &lBCFs{
		client: c.RESTClient(),
	}
}

// Get takes name of the lBCF, and returns the corresponding lBCF object, and an error if there is any.
func (c *lBCFs) Get(name string, options metav1.GetOptions) (result *v1.LBCF, err error) {
	result = &v1.LBCF{}
	err = c.client.Get().
		Resource("lbcfs").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of LBCFs that match those selectors.
func (c *lBCFs) List(opts metav1.ListOptions) (result *v1.LBCFList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1.LBCFList{}
	err = c.client.Get().
		Resource("lbcfs").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested lBCFs.
func (c *lBCFs) Watch(opts metav1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("lbcfs").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a lBCF and creates it.  Returns the server's representation of the lBCF, and an error, if there is any.
func (c *lBCFs) Create(lBCF *v1.LBCF) (result *v1.LBCF, err error) {
	result = &v1.LBCF{}
	err = c.client.Post().
		Resource("lbcfs").
		Body(lBCF).
		Do().
		Into(result)
	return
}

// Update takes the representation of a lBCF and updates it. Returns the server's representation of the lBCF, and an error, if there is any.
func (c *lBCFs) Update(lBCF *v1.LBCF) (result *v1.LBCF, err error) {
	result = &v1.LBCF{}
	err = c.client.Put().
		Resource("lbcfs").
		Name(lBCF.Name).
		Body(lBCF).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *lBCFs) UpdateStatus(lBCF *v1.LBCF) (result *v1.LBCF, err error) {
	result = &v1.LBCF{}
	err = c.client.Put().
		Resource("lbcfs").
		Name(lBCF.Name).
		SubResource("status").
		Body(lBCF).
		Do().
		Into(result)
	return
}

// Delete takes name of the lBCF and deletes it. Returns an error if one occurs.
func (c *lBCFs) Delete(name string, options *metav1.DeleteOptions) error {
	return c.client.Delete().
		Resource("lbcfs").
		Name(name).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched lBCF.
func (c *lBCFs) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.LBCF, err error) {
	result = &v1.LBCF{}
	err = c.client.Patch(pt).
		Resource("lbcfs").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
