/*
 * Tencent is pleased to support the open source community by making TKEStack
 * available.
 *
 * Copyright (C) 2012-2019 Tencent. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use
 * this file except in compliance with the License. You may obtain a copy of the
 * License at
 *
 * https://opensource.org/licenses/Apache-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

// Code generated by client-gen. DO NOT EDIT.

package v1

import (
	"time"

	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
	scheme "tkestack.io/tke/api/client/clientset/versioned/scheme"
	v1 "tkestack.io/tke/api/platform/v1"
)

// LogCollectorsGetter has a method to return a LogCollectorInterface.
// A group's client should implement this interface.
type LogCollectorsGetter interface {
	LogCollectors() LogCollectorInterface
}

// LogCollectorInterface has methods to work with LogCollector resources.
type LogCollectorInterface interface {
	Create(*v1.LogCollector) (*v1.LogCollector, error)
	Update(*v1.LogCollector) (*v1.LogCollector, error)
	UpdateStatus(*v1.LogCollector) (*v1.LogCollector, error)
	Delete(name string, options *metav1.DeleteOptions) error
	Get(name string, options metav1.GetOptions) (*v1.LogCollector, error)
	List(opts metav1.ListOptions) (*v1.LogCollectorList, error)
	Watch(opts metav1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.LogCollector, err error)
	LogCollectorExpansion
}

// logCollectors implements LogCollectorInterface
type logCollectors struct {
	client rest.Interface
}

// newLogCollectors returns a LogCollectors
func newLogCollectors(c *PlatformV1Client) *logCollectors {
	return &logCollectors{
		client: c.RESTClient(),
	}
}

// Get takes name of the logCollector, and returns the corresponding logCollector object, and an error if there is any.
func (c *logCollectors) Get(name string, options metav1.GetOptions) (result *v1.LogCollector, err error) {
	result = &v1.LogCollector{}
	err = c.client.Get().
		Resource("logcollectors").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of LogCollectors that match those selectors.
func (c *logCollectors) List(opts metav1.ListOptions) (result *v1.LogCollectorList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1.LogCollectorList{}
	err = c.client.Get().
		Resource("logcollectors").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested logCollectors.
func (c *logCollectors) Watch(opts metav1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("logcollectors").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a logCollector and creates it.  Returns the server's representation of the logCollector, and an error, if there is any.
func (c *logCollectors) Create(logCollector *v1.LogCollector) (result *v1.LogCollector, err error) {
	result = &v1.LogCollector{}
	err = c.client.Post().
		Resource("logcollectors").
		Body(logCollector).
		Do().
		Into(result)
	return
}

// Update takes the representation of a logCollector and updates it. Returns the server's representation of the logCollector, and an error, if there is any.
func (c *logCollectors) Update(logCollector *v1.LogCollector) (result *v1.LogCollector, err error) {
	result = &v1.LogCollector{}
	err = c.client.Put().
		Resource("logcollectors").
		Name(logCollector.Name).
		Body(logCollector).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *logCollectors) UpdateStatus(logCollector *v1.LogCollector) (result *v1.LogCollector, err error) {
	result = &v1.LogCollector{}
	err = c.client.Put().
		Resource("logcollectors").
		Name(logCollector.Name).
		SubResource("status").
		Body(logCollector).
		Do().
		Into(result)
	return
}

// Delete takes name of the logCollector and deletes it. Returns an error if one occurs.
func (c *logCollectors) Delete(name string, options *metav1.DeleteOptions) error {
	return c.client.Delete().
		Resource("logcollectors").
		Name(name).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched logCollector.
func (c *logCollectors) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.LogCollector, err error) {
	result = &v1.LogCollector{}
	err = c.client.Patch(pt).
		Resource("logcollectors").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
